@@ -1,4 +1,3 @@
-import requests
 import pandas as pd
 from pathlib import Path
 from datetime import datetime
@@ -6,6 +5,9 @@ import numpy as np
 from scipy import signal
 
 import matplotlib.pyplot as plt
+import matplotlib
+matplotlib.use("pdf")
+
 from rich.progress import track
 
 from cpmax_toolbox.file_repair import repair_file, parse_path
@@ -18,13 +20,12 @@ import typing
 
 
 def _ping_nano():
-    return b"NanoVib" in subprocess.check_output("netsh wlan show interfaces")
+    return b"NanoVib" in subprocess.check_output("netsh wlan show interfaces", shell=True)
 
 
-def _get_most_recent_measurement() -> Path:
-    dl_path = Path.home() / "Downloads"
-    most_recent_measurement = dl_path / "CON" / "00010101_000000_combined.txt"
-    for p0 in dl_path.iterdir():
+def _get_most_recent_measurement(folder_to_analyze: Path = (Path() / "Downloads")) -> Path:
+    most_recent_measurement = folder_to_analyze / "CON" / "00010101_000000_combined.txt"
+    for p0 in folder_to_analyze.iterdir():
         if not p0.is_dir():
             continue
 
@@ -42,36 +43,29 @@ def _get_most_recent_measurement() -> Path:
     return most_recent_measurement
 
 
-def continuous_analyzing() -> None:
+def continuous_analyzing(folder_to_analyze: Path = (Path() / "Downloads")) -> None:
     tnow = 10 * int(time.time() // 10)
     delta = 1
-    last_analyzing = [Path() / "Downloads" / "CON" / "00010101_000000_combined.txt", 0]
+    last_analyzing = [folder_to_analyze / "CON" / "00010101_000000_combined.txt", 0]
     while True:
         tnow = wait_until(tnow, delta)
         if not _ping_nano():
-            # print("No nano found -> 15s")
             delta = 15
             continue
 
-        # print("Searching file...")
         p_last_measurement = _get_most_recent_measurement()
         if not p_last_measurement.exists():
-            # print("No file found -> 30s")
             delta = 30
             continue
-        # print(f"Most recent File: {p_last_measurement}")
 
         if last_analyzing[0] != p_last_measurement:
-            # print("is new!")
             last_analyzing = [p_last_measurement, 0]
 
         if p_last_measurement.stat().st_size == last_analyzing[1]:
-            # print("size not changed -> 10s")
             delta = 10
             continue
 
         if time.time() - p_last_measurement.stat().st_mtime < 5:
-            # print("too fresh -> 5s")
             delta = 5
             continue
 
@@ -101,9 +95,7 @@ def continuous_analyzing() -> None:
                 found = True
 
         if not found:
-            # print("creating specs...")
             create_specs(df_ang, output_pdf, prefix=prefix)
-            # print("done")
 
         last_analyzing = [p_last_measurement, p_last_measurement.stat().st_size]
 
